/*
 * Copyright (c) 2003 Shinji Kashihara. All rights reserved.
 * 
 * This program and the accompanying materials are made available under
 * the terms of the Common Public License v1.0 which accompanies
 * this distribution, and is available at cpl-v10.html.
 */
package mergedoc.core;

import java.io.File;
import java.nio.charset.Charset;

import mergedoc.xml.ReplaceEntry;


/**
 * マージ設定インターフェースです。
 * @author Shinji Kashihara
 */
public interface Preference {

    /**
     * API ドキュメントディレクトリを取得します。
     * @return API ドキュメントディレクトリ
     */
    File getDocDirectory();

    /**
     * 入力ソースアーカイブファイルを取得します。
     * @return 入力ソースアーカイブファイル
     */
    File getInputArchive();

    /**
     * 出力ソースアーカイブファイルを取得します。
     * @return 出力ソースアーカイブファイル
     */
    File getOutputArchive();

    /**
     * API ドキュメントエンコーディングを取得します。
     * @return API ドキュメントエンコーディング
     */
    Charset getDocEncoding();

    /**
     * 入力ソースエンコーディングを取得します。
     * @return 入力ソースエンコーディング
     */
    Charset getInputEncoding();

    /**
     * 出力ソースエンコーディングを取得します。
     * @return 出力ソースエンコーディング
     */
    Charset getOutputEncoding();

    /**
     * グローバル置換エントリの配列を取得します。
     * @return グローバル置換エントリの配列
     */
    ReplaceEntry[] getGlobalEntries();
}
